#include "config.h"

ConfigDlg::ConfigDlg (QList<RecipientList>*l)
{
	setupUi(this);
	list=l;
	for(int i=0;i<list->count();i++){
		recipientLists->insertRow(recipientLists->rowCount());
		recipientLists->setItem(i,0,new QTableWidgetItem(list->value(i).name));
		recipientLists->setItem(i,1,new QTableWidgetItem(list->value(i).alias));
		recipientLists->setItem(i,2,new QTableWidgetItem(list->value(i).ending));
	}
	readSettings();
	connect(this,SIGNAL(accepted()),this,SLOT(writeSettings()));
}

int ConfigDlg::getSendingMode()
{
	if(sendMailTo->isChecked()) return 1;
	if(sendMailBcc->isChecked()) return 2;
	if(sendMailIndividual->isChecked()) return 3;
	return -1;
}

void ConfigDlg::on_addListButton_clicked()
{
	recipientLists->insertRow(recipientLists->rowCount());
}

void ConfigDlg::on_downloadRcptList_clicked(bool clicked)
{
	if(clicked)ftpBox->setChecked(true);
}

void ConfigDlg::writeSettings()
 {
	QSettings settings("KiSoft", "Newsletter");
	settings.beginGroup("General");
	settings.setValue("GetCatOnStart",getCatOnStart->isChecked());
	settings.endGroup();
	settings.beginGroup("Mail");
	settings.setValue("Username",smtpUsr->text());
	settings.setValue("Password",smtpPwd->text());
	settings.setValue("Host",smtpHost->text());
	settings.setValue("Login",smtpLogin->isChecked());
	settings.setValue("SendingMode",getSendingMode());
	settings.setValue("MaxRcpt",maxRcpt->text());
	settings.endGroup();
	settings.beginGroup("Recipients");
	settings.setValue("Username",ftpUsr->text());
	settings.setValue("Password",ftpPwd->text());
	settings.setValue("Host",ftpHost->text());
	settings.setValue("CategoryFile",ftpCategoryFile->text());
	settings.setValue("Path",ftpPath->text());
	settings.setValue("Login",ftpLogin->isChecked());
	settings.setValue("DownloadLists",ftpBox->isChecked());
	settings.setValue("DownloadRcptList",downloadRcptList->isChecked());
	settings.endGroup();
	settings.beginGroup("Paths");
	settings.setValue("Groups",catPath->text());
	//settings.setValue("Archive",pathArchive);
	//settings.setValue("Plugins",pathPlugins);
	settings.setValue("Header",headerPath->text());
	settings.endGroup();
	
	if(list->count()>0)list->clear();
	for(int i=0;i<recipientLists->rowCount();i++){
		RecipientList r;
		r.name=recipientLists->item(i,0)->text();
		r.alias=recipientLists->item(i,1)->text();
		r.ending=recipientLists->item(i,2)->text();
		if(!r.ending.contains("."))r.ending.insert(0,".");
		list->append(r);
	}
 }
 
 void ConfigDlg::readSettings()
 {
 	QSettings settings("KiSoft", "Newsletter");
 	settings.beginGroup("General");
	getCatOnStart->setChecked(settings.value("GetCatOnStart",false).toBool());
	settings.endGroup();
	settings.beginGroup("Mail");
	smtpHost->setText(settings.value("Host","").toString());
	smtpUsr->setText(settings.value("Username","").toString());
	smtpPwd->setText(settings.value("Password","").toString());
	smtpLogin->setChecked(settings.value("Login","").toBool());
	setSendingMode(settings.value("SendingMode",1).toInt());
	maxRcpt->setText(settings.value("MaxRcpt","100").toString());
	settings.endGroup();
	settings.beginGroup("Recipients");
	ftpHost->setText(settings.value("Host","").toString());
	ftpUsr->setText(settings.value("Username","").toString());
	ftpPwd->setText(settings.value("Password","").toString());
	ftpCategoryFile->setText(settings.value("CategoryFile","").toString());
	ftpPath->setText(settings.value("Path","").toString());
	ftpLogin->setChecked(settings.value("Login","").toBool());
	downloadRcptList->setChecked(!settings.value("DownloadRcptList","").toBool());
	downloadRcptList->toggle();
	ftpBox->setChecked(!settings.value("DownloadLists","").toBool());
	settings.endGroup();
	settings.beginGroup("Paths");
	catPath->setText(settings.value("Groups","").toString());
	headerPath->setText(settings.value("Header","").toString());
	settings.endGroup();
}
 
void ConfigDlg::setSendingMode(int mode)
{
	switch(mode)
	{
 	case 1:
		sendMailTo->setChecked(true);
		sendMailBcc->setChecked(false);
 		sendMailIndividual->setChecked(false);	
		break;
	case 2:
		sendMailTo->setChecked(false);
 		sendMailBcc->setChecked(true);	
 		sendMailIndividual->setChecked(false);	
 		break;
	case 3:
		sendMailTo->setChecked(false);
		sendMailBcc->setChecked(false);
 		sendMailIndividual->setChecked(true);	
		break;
	}

 		
}
