#include "mainwindowimpl.h"
#include "replace.h"
#include "smtp.h"
#include <QProgressBar>
#include "log.h"


//
MainWindowImpl::MainWindowImpl( QWidget * parent, Qt::WFlags f) 
	: QMainWindow(parent, f)
{
	catFileName="categories.txt";
	setupUi(this);
	createStatusbar();
	createDockWidgets();
	
	connect(sendMail,SIGNAL(clicked()),this,SLOT(sendMails()));
	
	connect(action_Config,SIGNAL(triggered()),this,SLOT(loadConfigDlg()));
	connect(action_Auto_Replace,SIGNAL(triggered()),this,SLOT(loadReplaceDlg()));
	connect(action_Replace,SIGNAL(triggered()),this,SLOT(replaceText()));
	
	connect(tabWidget,SIGNAL(currentChanged(int)),this,SLOT(updateText(int)));
	connect(action_Refresh_Categories,SIGNAL(triggered()),this,SLOT(refreshCategories()));
	connect(catList,SIGNAL(itemSelectionChanged()),this,SLOT(updateToList()));
	connect(action_Open,SIGNAL(triggered()),this,SLOT(openFile()));
	connect(actionSave_as,SIGNAL(triggered()),this,SLOT(saveFileAs()));
	connect(action_Save,SIGNAL(triggered()),this,SLOT(saveFile()));
		
	readSettings();
	
	log = new Log(logText,"log.txt",0);
	
	if(fName=="")newFile();
	else openFile(fName);
	
	ftp = new QFtp(this);
	
	if (getCatOnStart) refreshCategories();
	else readCategories();
}

void MainWindowImpl::createStatusbar()
{
	state = new QLabel("Ready...",this);
	//state->setAlignment(Qt::AlignHCenter);
	//state->setMinimumSize(state->sizeHint());
	
	date = new QLabel(QDateTime::currentDateTime().toString("dd.MM.yy hh:mm"),this);
	date->setAlignment(Qt::AlignHCenter);
	date->setMinimumSize(state->sizeHint());
	
	progressBar = new QProgressBar(this);
	progressBar->setMinimumWidth(150);
	
	statusBar()->addWidget(progressBar);
	statusBar()->addWidget(state,1);
	statusBar()->addWidget(date);
}

void MainWindowImpl::createDockWidgets()
{
	QDockWidget *dock = new QDockWidget(tr("Log"),this);
	dock->setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
	logText = new QTextEdit(this);
	dock->setWidget(logText);
	addDockWidget(Qt::RightDockWidgetArea, dock);
	menu_View->addAction(dock->toggleViewAction());
}

void MainWindowImpl::readSettings()
{
	QSettings settings("KiSoft", "Newsletter");
	settings.beginGroup("General");
	getCatOnStart = settings.value("GetCatOnStart",false).toBool();
	fName=settings.value("LastFile","").toString();
	settings.endGroup();
	settings.beginGroup("Window");
	QPoint pos = settings.value("pos", QPoint(200, 200)).toPoint();
	QSize size = settings.value("size", QSize(400, 400)).toSize();
	resize(size);
	move(pos);
	settings.endGroup();
	settings.beginGroup("Mail");
	smtpHost=settings.value("Host","").toString();
	smtpUsr=settings.value("Username","").toString();
	smtpPwd=settings.value("Password","").toString();
	sendingMode=settings.value("SendingMode","1").toInt();
	maxRcpt=settings.value("MaxRcpt","100").toInt();
	settings.endGroup();
	settings.beginGroup("Recipients");
	ftpHost=settings.value("Host","").toString();
	ftpUsr=settings.value("Username","").toString();
	ftpPwd=settings.value("Password","").toString();
	ftpCategoryFile=settings.value("CategoryFile","").toString();
	categoryFile=ftpCategoryFile.mid(ftpCategoryFile.lastIndexOf("/")+1);
	ftpPath=settings.value("Path","").toString();
	downloadLists=settings.value("DownloadLists","").toBool();
	downloadRcptList=settings.value("DownloadRcptList","").toBool();
	settings.endGroup();
	settings.beginGroup("Paths");
	pathGroup=settings.value("Groups","").toString();
	pathHeader=settings.value("Header","").toString();
	settings.endGroup();
	settings.beginGroup("TextEdit");
	int anz = settings.value("ReplaceListCount",0).toInt();
	replaceList.clear();
	for (int i=0;i<anz;i++)
	{
		QString source = QString("ReplaceItemSource%1").arg(i+1);
		QString target = QString("ReplaceItemTarget%1").arg(i+1);
		QPair<QString,QString> pair(settings.value(source,"").toString(),settings.value(target,"").toString());
		if (source!="") replaceList.append(pair);
	};
	settings.endGroup();
}

void MainWindowImpl::writeSettings()
{
	QSettings settings("KiSoft", "Newsletter");
	
	settings.beginGroup("General");
	settings.setValue("GetCatOnStart",getCatOnStart);
	settings.setValue("LastFile",fName);
	settings.endGroup();
	settings.beginGroup("Window");
	settings.setValue("pos", pos());
	settings.setValue("size", size());
	settings.endGroup();
	settings.beginGroup("Mail");
	settings.setValue("Username",smtpUsr);
	settings.setValue("Password",smtpPwd);
	settings.setValue("Host",smtpHost);
	settings.endGroup();
	settings.beginGroup("Recipients");
	settings.setValue("Username",ftpUsr);
	settings.setValue("Password",ftpPwd);
	settings.setValue("Host",ftpHost);
	settings.setValue("CategoryFile",ftpCategoryFile);
	settings.endGroup();
	settings.beginGroup("Paths");
	settings.setValue("Groups",pathGroup);
	settings.setValue("Archive",pathArchive);
	settings.setValue("Plugins",pathPlugins);
	settings.setValue("Header",pathHeader);
	settings.endGroup();
	settings.beginGroup("TextEdit");
	settings.setValue("ReplaceListCount",replaceList.count());
	for (int i=0;i<replaceList.count();i++)
	{
		settings.setValue(QString("ReplaceItemSource%1").arg(i+1),replaceList[i].first);
		settings.setValue(QString("ReplaceItemTarget%1").arg(i+1),replaceList[i].second);
	};
	settings.endGroup();
}
 
void MainWindowImpl::loadHeader()
{
		QFile file;
	if (pathHeader!="")
	{
		QDir dir = QDir::current();
		
     	if (!dir.exists(pathHeader)) dir.mkdir(pathHeader);
     	dir.cd(pathHeader);

         file.setFileName(dir.filePath("header.txt"));
	} else file.setFileName("header.txt");
	if (file.open(QFile::ReadOnly | QFile::Text)) htmlHeader->setPlainText(QString(file.readAll()));
	
	file.close();

	if (pathHeader!="")
	{
		QDir dir = QDir::current();
		
     	if (!dir.exists(pathHeader)) dir.mkdir(pathHeader);
     	dir.cd(pathHeader);

         file.setFileName(dir.filePath("footer.txt"));
	} else file.setFileName("footer.txt");
	if (file.open(QFile::ReadOnly | QFile::Text)) htmlFooter->setPlainText(QString(file.readAll()));
	file.close	();
}

void MainWindowImpl::loadConfigDlg()
{
	ConfigDlg dialog(&Groups);
	if (dialog.exec()){
		readSettings();
		readCategories();
	}
	return;
}

void MainWindowImpl::loadReplaceDlg()
{
	ReplaceDlg dialog(&replaceList);	
	dialog.exec();
	return;
}

void MainWindowImpl::newFile()
{
	from->setText("");
	fromName->setText("");
	subject->setText("");
	htmlHeader->setPlainText("");
	htmlBody->setPlainText("");
	htmlFooter->setPlainText("");
	updateText(1);
	updateText(2);
	updateText(3);
	loadHeader();
	if (tabWidget->currentIndex()!=0) updateText(tabWidget->currentIndex());
}

void MainWindowImpl::on_txtCleartext_textChanged()
{
	clearTextChanged=true;
}

void MainWindowImpl::openFile()
{
	QString filters;
	filters.append(tr("NewsletterCreator files (*.nlc *.txt *.html *.htm)"));
	//filters.append(tr("Text files (*.txt)"));
	//filters.append(tr("HTML files (*.html)"));
	//filters.append(tr("HTM files (*.htm)"));
	
	fName=QFileDialog::getOpenFileName(this, tr("Open File"), "", filters);
	openFile(fName);
}

void MainWindowImpl::openFile(QString fileName)
{
	QFile file(fileName);
	
	if (!file.open(QIODevice::ReadOnly)) return;

	
	if (file.fileName().contains(".nlc",Qt::CaseInsensitive))
    {
    	//qDebug() << "start Reading";
    	QDataStream in(&file);
		in.setVersion(QDataStream::Qt_4_0);
			
		quint32 magic;
		qint32 version;
		
		in >> magic;			
		if (magic != MagicNumber){
			log->addEntry(tr("File has wrong signature"));
			return;
		}
		in >> version;

		qint32 lenHeader, lenBody, lenFooter;
		in >> lenHeader >> lenBody >> lenFooter;
		
		//qDebug() << lenHeader << lenBody << lenFooter;

		QString tempT;

		in >> tempT;
		from->setText(tempT);
		if (version==2){
			in>>tempT;
			fromName->setText(tempT);
		}
		in >> tempT;
		subject->setText(tempT);
		in >> tempT;
		htmlHeader->setPlainText(tempT);
		in >> tempT;
		htmlBody->setPlainText(tempT);
		in >> tempT;
		htmlFooter->setPlainText(tempT); 	
		in>>tempT;
		txtCleartext->setPlainText(tempT);

		if(version==1){
			in>>clearTextChanged;
		}else clearTextChanged=false;
    }
    else if (file.fileName().contains(".htm",Qt::CaseInsensitive) || file.fileName().contains(".html",Qt::CaseInsensitive))
    {
    	htmlBody->setPlainText(file.readAll());
   	}
}

void MainWindowImpl::saveFile()
{
	if (fName!="")
	{
		saveFile(fName);
		return;
	}
	
	saveFileAs();
	
}

void MainWindowImpl::saveFile(QString fileName)
{
	if (!fileName.contains(".htm",Qt::CaseInsensitive) &&
		 !fileName.contains(".html",Qt::CaseInsensitive) &&
		 !fileName.contains(".nlc",Qt::CaseInsensitive) &&
		 !fileName.contains(".txt",Qt::CaseInsensitive)) fileName.append(".nlc");
		 
	QFile file(fileName);
	
	if (!file.open(QIODevice::WriteOnly)) return;
     
    if (fileName.contains(".nlc",Qt::CaseInsensitive))
    {
		QDataStream out(&file);
     	out << (quint32)MagicNumber;
     	out << (qint32)2; //file version
		out.setVersion(QDataStream::Qt_4_0);
		out << (qint32)htmlHeader->toPlainText().length();
		out << (qint32)htmlBody->toPlainText().length();		
		out << (qint32)htmlFooter->toPlainText().length();
		out << from->text();
		out << fromName->text();
		out << subject->text();	
     	out << htmlHeader->toPlainText();
     	out << htmlBody->toPlainText();
     	out << htmlFooter->toPlainText();
     	out << txtCleartext->toPlainText();
     	out << clearTextChanged;
    }
    else if (file.fileName().contains(".htm",Qt::CaseInsensitive) || file.fileName().contains(".html",Qt::CaseInsensitive)|| file.fileName().contains(".txt",Qt::CaseInsensitive))
    {
		QTextStream out(&file);
		QString text = htmlHeader->toPlainText();
		text.append(htmlBody->toPlainText());
		text.append(htmlFooter->toPlainText());
		text.replace("$Date",QDate::currentDate().toString("dddd, dd. MMMM yyyy"));
		
     	out << text; 
	}
}

void MainWindowImpl::saveFileAs()
{
	QString filters;
	filters.append(tr("NewsletterCreator files (*.nlc *.txt *.html *.htm)"));
	//filters.append(tr("Text files (*.txt)"));
	//filters.append(tr("HTML files (*.html)"));
	//filters.append(tr("HTM files (*.htm)"));
	
	fName=QFileDialog::getSaveFileName(this, tr("Save File"), "", filters);
	saveFile(fName);
}

void MainWindowImpl::sendMails()
{
	log->addEntry(tr("Start mailing process"));
	state->setText(tr("Start mailing process"));
	rcptList = new QStringList();
	for (int i=0;i<toList->count();i++)
	{
		rcptList->append(toList->item(i)->text());
	};
	
	if (rcptList->count()==0){
		log->addEntry(tr("Found no adresse to send newsletter to"));
		return;
	}
	
	log->addEntry(tr("Found %1 adresse(s)").arg(rcptList->count()));
	updateDataTransferProgress(0,rcptList->count());

	newMail  = new Smtp();
	
	connect(newMail,SIGNAL(ReadyToSend()),this,SLOT(sendNextMail()));
	connect(newMail,SIGNAL(ErrorCloseAll()),this,SLOT(mailSendError()));
	connect(newMail,SIGNAL(SuccessQuit()),this,SLOT(mailDisconnected()));
	
	newMail->ini(smtpUsr, smtpPwd, smtpHost);

}

void MainWindowImpl::mailSendError()
{
	newMail->disconnect();
}

void MainWindowImpl::sendNextMail()
{

	if(!newMail) return;
	static QString to="";
	static QStringList bcc;
	static int mailCount=1;
	
    if (newMail->error){
		log->addEntry(tr("Error in sending process"));   	
		return;
	}
    if (to!="") state->setText(tr("Mail successfully sent"));  
    
	updateDataTransferProgress(progressBar->maximum() - rcptList->count(),-1);
	state->setText(tr("Sening Mail (%1 of %2)").arg(rcptList->count()).arg(progressBar->maximum()));
	
	//updateText(2);	
	QString bodyHtml = QString(htmlHeader->toPlainText() + htmlBody->toPlainText() + htmlFooter->toPlainText());
	bodyHtml.replace("$Date",QDate::currentDate().toString("dddd, dd. MMMM yyyy"));
	QString bodyPlain = txtCleartext->toPlainText();

	if (rcptList->count()==0)
	{
		QApplication::setOverrideCursor(Qt::ArrowCursor);
		state->setText(tr("All mails sent"));
		log->addEntry(tr("All mails sent"));
		newMail->disconnectSmtp();
		state->setText(tr("Ready..."));
		updateDataTransferProgress(0,0);
		return;
	}

	if(sendingMode==1)
	{
		to="";
		int i=1;
		while(rcptList->size()>0)
		{
			if(to=="")to=rcptList->takeFirst();
			else to.append(", "+rcptList->takeFirst());
			if(i==maxRcpt) break;
			i++;
		}
		
		QString msg=tr("Sending Mail %1 of %2").arg(toList->count()-rcptList->count()).arg(toList->count()).arg(to);
		state->setText(msg);
		log->addEntry(msg);			
	}else if(sendingMode==2){
		bcc.clear();
		int i=1;
		while(rcptList->size()>0)
		{
			bcc.append(rcptList->takeFirst());
			if(i==maxRcpt) break;
			i++;
		}
		to="webmaster@alti-moschti.ch";
		qDebug()<<int(rcptList->count()/maxRcpt);
		QString msg=tr("Sending mail %1 of %2").arg(mailCount).arg(int(rcptList->count()/maxRcpt)+1);
		state->setText(msg);
		log->addEntry(msg);
	}else if(sendingMode==3){
		to=rcptList->takeFirst();
		
		QString msg=tr("Sending Mail %1 of %2 to %3").arg(toList->count()-rcptList->count()).arg(toList->count()).arg(to);
		state->setText(msg);
		log->addEntry(msg);	
	}
	
	QCoreApplication::processEvents();
	
	QApplication::setOverrideCursor(Qt::WaitCursor);
	
	newMail->sendMail(from->text(),to,bcc,subject->text(),"Alti Moschti",bodyHtml,bodyPlain);
}

void MainWindowImpl::mailDisconnected()
{
	if(!newMail) return;
	qDebug()<<"delete";
	disconnect(newMail,SIGNAL(ReadyToSend()),this,SLOT(sendNextMail()));
	disconnect(newMail,SIGNAL(ErrorCloseAll()),this,SLOT(mailSendError()));
	disconnect(newMail,SIGNAL(SuccessQuit()),this,SLOT(mailDisconnected()));
	newMail->deleteLater();
	qDebug()<<"deleted";
}

void MainWindowImpl::refreshCategories()
{
	log->addEntry(tr("Start refreshing categories..."));
	//qDebug()<<categoryFile<<ftpCategoryFile.left(ftpCategoryFile.lastIndexOf("/"));
	if(downloadRcptList) getFileFTP(categoryFile,ftpCategoryFile.left(ftpCategoryFile.lastIndexOf("/")));
	else readCategories();
	if(downloadLists){
		log->addEntry(tr("Start downloading %1 categories...").arg(Groups.count()));
		QString fName=Groups[0].alias+Groups[0].ending;
		getFileFTP(fName);
	}
}

void MainWindowImpl::readCategories()
{
	QFile localFile;
	
	if (pathGroup!="")
	{
		QDir dir = QDir::current();
     	dir.cd(pathGroup);

		localFile.setFileName(dir.filePath(catFileName));
	} else localFile.setFileName(catFileName);
	
     if (!localFile.open(QIODevice::ReadOnly)) {
         QMessageBox::information(this, tr("Load categories"),
                                  tr("Unable to open the file %1: %2.")
                                  .arg(localFile.fileName()).arg(localFile.errorString()));
         log->addEntry(tr("ERROR: Unable to open category-file %1: %2").arg(localFile.fileName()).arg(localFile.errorString()));
         return;
	} 

	catList->clearSelection();
	catList->clear();
	if(Groups.count()>0)Groups.clear();
			
	QTextStream in(&localFile);
	while(!in.atEnd()) {
		QString s;
		s=in.readLine();
		if(s!="")
		{
			RecipientList r;
			r.alias=s.section(";",0,0);
			r.name=s.section(";",1,1);
			r.ending=s.section(";",2,2);
			Groups.append(r);
			catList->addItem(r.name);			
		}
	}
	localFile.close();	
	
	catCount->setText(tr("%1 categories").arg(catList->count()));
	
	log->addEntry(tr("Found %1 categories.").arg(Groups.count()));
}

void MainWindowImpl::getFileFTP(QString filename,QString dir)
{
	if (dir=="") dir=ftpPath;
	//qDebug()<<dir<<ftpPath;
	setCursor(Qt::WaitCursor);
	
	if (ftp)
	{
		ftp->abort();
		ftp->deleteLater();
		ftp = 0;
	}
		
	ftp = new QFtp(this);
	
	connect(ftp, SIGNAL(commandFinished(int, bool)), this, SLOT(ftpCommandFinished(int, bool)));
	connect(ftp, SIGNAL(dataTransferProgress(qint64, qint64)), this, SLOT(updateDataTransferProgress(qint64, qint64)));
	
	ftp->setTransferMode(QFtp::Active); //
	ftp->connectToHost(ftpHost);
	ftp->login(ftpUsr,ftpPwd);
	ftp->cd(dir);
	
	if (pathGroup!="")
	{
		QDir dir = QDir::current();                 
		
     	if (!dir.exists(pathGroup)) dir.mkdir(pathGroup);
     	dir.cd(pathGroup);
        file = new QFile(dir.filePath(filename),this);
	} else file = new QFile(filename,this);

	//qDebug() << "Dateiname: " << filename;
	
     if (!file->open(QIODevice::WriteOnly)) {
         QMessageBox::information(this, tr("FTP"),
                                  tr("Unable to save the file %1: %2.")
                                  .arg("all.txt").arg(file->errorString()));
         delete file;
         return;
     }

	ftp->get(filename, file);
	log->addEntry(tr("Downloading %1").arg(filename));
	state->setText(tr("Downloading %1").arg(filename));
}

void MainWindowImpl::convertCatFile()
{
	QFile localFile;
	QFile newFile;
	
	if (pathGroup!="")
	{
		QDir dir = QDir::current();
     	dir.cd(pathGroup);

		localFile.setFileName(dir.filePath(categoryFile));
		newFile.setFileName(dir.filePath(catFileName));
	} else{
		localFile.setFileName(categoryFile);
		newFile.setFileName(catFileName);
	}

	localFile.open(QIODevice::ReadOnly);
	if(Groups.count()>0)Groups.clear();
	QTextStream in(&localFile);
	QString line=in.readLine();
		
	while (!line.isNull()) {
		line=in.readLine();
			
		int pos1 = line.indexOf("'",6);
		int pos2 = line.indexOf('"');
		int pos3 = line.indexOf('"',pos2+1);
		
		QString alias = line.mid(6,pos1-6);
		QString name = line.mid(pos2+1,pos3-pos2-1);
		
		if (name != "" && name != "?>"){
			RecipientList r;
			r.name=name;
			r.alias=alias;
			r.ending=".txt";
			Groups.append(r);		
		}
	}
	localFile.close();
	newFile.open(QIODevice::WriteOnly);
	QTextStream out(&newFile);
	for(int i=0;i<Groups.count();i++) {
		out<<"\n"+Groups[i].alias+";"+Groups[i].name+";"+Groups[i].ending;
	}
	newFile.close();	
}

void MainWindowImpl::ftpCommandFinished(int, bool error)
{
     setCursor(Qt::ArrowCursor);

     if (ftp->currentCommand() == QFtp::ConnectToHost) {
         if (error) {
         	QString message=tr("Unable to connect to the FTP server "
                                         "at %1. Please check that the host "
                                         "name is correct.")
                                      .arg(ftpHost);
             QMessageBox::information(this, tr("FTP"),message);
             //connectOrDisconnect();
             return;
         }

         state->setText(tr("Logged onto %1.").arg(ftpHost));

         return;
     }

     if (ftp->currentCommand() == QFtp::Get) {
     	
     	QString fileName = file->fileName();
        
         if (error) {
         	QString message=tr("Download-Error: %1").arg(ftp->errorString());
         	qDebug()<<ftp->hasPendingCommands();
			log->addEntry(message);                   
			state->setText(tr("Canceled download of %1.").arg(fileName));
			file->remove();
			file->close();
         } else {
             state->setText(tr("Downloaded %1 to current directory.").arg(fileName));
             //file=0;
             if(fileName.indexOf(categoryFile)!=-1){
				
				file->close();
			    delete file;
				
				convertCatFile();
				readCategories();				
			 } else {
					for(int i=0;Groups.count();i++)
					{
						QString name=Groups[i].alias + Groups[i].ending;
						int posName = fileName.indexOf(name);
						int pos = fileName.indexOf('/',posName-1);
			             if(posName!=-1 && pos!=-1)
			             {
							log->addEntry(tr("%1 downloaded. Size : %2 B").arg(name).arg(file->size()));
							
							file->close();
			             	delete file;
							
							if (i==Groups.count()-1) break;
							name=Groups[i+1].alias + Groups[i+1].ending;
					        getFileFTP(name);
					        break;
						}				
					};
	
				}
				
         }

     }

 }
 
void MainWindowImpl::replaceText()
{
	QString tempT;
	if (tabWidget->currentIndex()!=0) updateText(0);
	for (int i=0;i<replaceList.count();i++)
	{
		tempT=htmlHeader->toPlainText();
		tempT.replace(replaceList[i].first,replaceList[i].second);
		htmlHeader->setPlainText(tempT);
		tempT=htmlBody->toPlainText();
		tempT.replace(replaceList[i].first,replaceList[i].second);
		htmlBody->setPlainText(tempT);
		tempT=htmlFooter->toPlainText();
		tempT.replace(replaceList[i].first,replaceList[i].second);
		htmlFooter->setPlainText(tempT);
	};
	if (tabWidget->currentIndex()!=0) updateText(tabWidget->currentIndex());
}

void MainWindowImpl::updateDataTransferProgress(qint64 readBytes,qint64 totalBytes)
{
    if (totalBytes != -1) progressBar->setMaximum(totalBytes);
    if (readBytes != -1) progressBar->setValue(readBytes);
}

void MainWindowImpl::updateText(int activeText)
{
	if (activeText==1)
	{
		if (updateWebOnChange->checkState()==Qt::Checked)
		{
			webHeader->setHtml(htmlHeader->toPlainText());
			webBody->setHtml(htmlBody->toPlainText());
			webFooter->setHtml(htmlFooter->toPlainText());	
		}
	}
	else if (activeText==0)
	{
		if (updateHtmlOnChange->checkState()==Qt::Checked)
		{
			htmlHeader->setPlainText(webHeader->toHtml());
			htmlBody->setPlainText(webBody->toHtml());	
			htmlFooter->setPlainText(webFooter->toHtml());
		}		
	}
	else if (activeText==2)
	{
		QString text = htmlHeader->toPlainText() + htmlBody->toPlainText() + htmlFooter->toPlainText();
		text.replace("$Date",QDate::currentDate().toString("dddd, dd. MMMM yyyy"));
		txtPreview->setHtml(text);
	}
	else if (activeText==3 && clearTextChanged==false)
	{
		QString text = htmlHeader->toPlainText() + htmlBody->toPlainText() + htmlFooter->toPlainText();
		text.replace("$Date",QDate::currentDate().toString("dddd, dd. MMMM yyyy"));
		txtPreview->setHtml(text);
		txtCleartext->setPlainText(txtPreview->toPlainText().toUtf8());		
	}
}

void MainWindowImpl::updateToList()
{

	toList->clear();
	
	QList<QListWidgetItem *> selItems(catList->selectedItems());
	
	for (int i=0;i<selItems.count();i++)
	{

		for (int j=0;j<Groups.count();j++)
		{
			if (Groups[j].name==selItems[i]->text())
			{
				
				QFile localFile;
				if (pathGroup!="")
				{
					QDir dir = QDir::current();
			     	dir.cd(pathGroup);
			
			        localFile.setFileName(dir.filePath(Groups[j].alias + Groups[j].ending));
				} else localFile.setFileName(Groups[j].alias + Groups[j].ending);
				
			     if (!localFile.open(QIODevice::ReadOnly)) {
			         QMessageBox::information(this, tr("Read recipient List"),
			                                  tr("Unable to open the file %1: %2.")
			                                  .arg(localFile.fileName()).arg(localFile.errorString()));
			         //delete localFile;
			         return;
				}     
			
				QTextStream in(&localFile);
				QString line=in.readLine();
					
				while (!line.isNull())
				{
					toList->addItem(line);
					line=in.readLine();
				}
				localFile.close();
				
				break;
			}
		};
	};
	toCount->setText(tr("%1 recipients").arg(toList->count()));
}

void MainWindowImpl::closeEvent(QCloseEvent *event)
 {
     //if (maybeSave()) {
         writeSettings();
         log->saveToFile();
         event->accept();
     //} else {
     //    event->ignore();
     //}
 }

