#include "replace.h"

ReplaceDlg::ReplaceDlg (QList<QPair<QString,QString> > *rList)
{
	setupUi(this);
	
	connect(addButton,SIGNAL(clicked()),this,SLOT(addPair()));
	connect(deleteButton,SIGNAL(clicked()),this,SLOT(deletePairs()));
	connect(okButton,SIGNAL(clicked()),this,SLOT(updatePairs()));
	connect(exportButton,SIGNAL(clicked()),this,SLOT(exportList()));
	connect(importButton,SIGNAL(clicked()),this,SLOT(importList()));
	
	connect(source,SIGNAL(textChanged(QString)),this,SLOT(updateAddState()));
	connect(lstSource,SIGNAL(itemSelectionChanged()),this,SLOT(updateDeleteState()));
	connect(lstSource,SIGNAL(itemSelectionChanged()),this,SLOT(updateTargetSelection()));
	connect(lstTarget,SIGNAL(itemSelectionChanged()),this,SLOT(updateSourceSelection()));
	
	replaceList=rList;
	
	fillListView();
	
	connect(this,SIGNAL(accepted()),this,SLOT(updatePairs()));
	//readSettings();
}

void ReplaceDlg::fillListView()
{
	int count = replaceList->count();
	

	lstSource->clearSelection();
	lstTarget->clearSelection();
	lstSource->clear();
	lstTarget->clear();
	
	for (int i=0;i<count;i++)
	{
		lstSource->addItem(replaceList->value(i).first);
		lstTarget->addItem(replaceList->value(i).second);
	};
}

void ReplaceDlg::addPair()
{
	lstSource->addItem(source->text());
	lstTarget->addItem(target->text());
	source->setText("");
	target->setText("");	
}

void ReplaceDlg::deletePairs()
{
	disconnect(lstSource,SIGNAL(itemSelectionChanged()),this,SLOT(updateTargetSelection()));
	disconnect(lstTarget,SIGNAL(itemSelectionChanged()),this,SLOT(updateSourceSelection()));
	
	if (lstSource->count() == 0) return;
	qDebug() << lstSource->count();
	for (int i=0;i<lstSource->count();i++)
	{
		qDebug() << i;
		if (lstSource->item(i)->isSelected())
		{	
			qDebug() << "Take item";
			lstSource->item(i)->setSelected(false);
			lstTarget->item(i)->setSelected(false);			

			lstSource->takeItem(i);
			qDebug() << "1st token";
			lstTarget->takeItem(i);
			qDebug() << "2nd token";
		}
	};

	connect(lstSource,SIGNAL(itemSelectionChanged()),this,SLOT(updateTargetSelection()));
	connect(lstTarget,SIGNAL(itemSelectionChanged()),this,SLOT(updateSourceSelection()));
}

void ReplaceDlg::updatePairs()
{
	replaceList->clear();
	for (int i=0;i<lstSource->count();i++)
	{
		replaceList->append(qMakePair(lstSource->item(i)->text(),lstTarget->item(i)->text()));
	};
}

void ReplaceDlg::updateAddState()
{
	if (source->text()!="") addButton->setEnabled(true);
	else addButton->setEnabled(false);
}

void ReplaceDlg::updateDeleteState()
{
	if (lstSource->selectedItems().count() > 0) deleteButton->setEnabled(true);
	else deleteButton->setEnabled(false);
}

void ReplaceDlg::updateSourceSelection()
{	qDebug()<< "start updateSourceSelection";
	for (int i=0;i<lstTarget->count();i++)
	{	qDebug()<<"in for loop at " << i;
		lstSource->item(i)->setSelected(lstTarget->item(i)->isSelected());
	};
	qDebug()<< "finish updateSourceSelection";
}

void ReplaceDlg::updateTargetSelection()
{	qDebug()<< "start updateTargetSelection";
	for (int i=0;i<lstTarget->count();i++)
	{
		lstTarget->item(i)->setSelected(lstSource->item(i)->isSelected());
	};
	qDebug()<< "finish updateTargetSelection";
}

void ReplaceDlg::importList()
{
	QString fileName=QFileDialog::getOpenFileName(this, tr("Open File"), "", tr("Textfiles (*.txt)"));
	
	replaceList->clear();
	
	QFile file(fileName);
	
	if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) return;
	
	QTextStream in(&file);
	QString line=in.readLine();
	
	while (!line.isNull())
	{
		QStringList list = line.split("\t");
		
		QPair<QString,QString> pair(list[0],list[1]);
		replaceList->append(pair);

		line=in.readLine();		
	}
	file.close();
	
	fillListView();
}

void ReplaceDlg::exportList()
{
	QString fileName=QFileDialog::getSaveFileName(this, tr("Save File"), "", tr("Textfiles (*.txt)"));
	if (fileName.indexOf(".txt",fileName.length()-4)==-1) fileName.append(".txt");
	
	QFile file(fileName);
	
	if (!file.open(QIODevice::WriteOnly | QIODevice::Text)) return;
	
	QTextStream out(&file);
	
	for (int i=0;i<lstSource->count();i++)
	{
		out << lstSource->item(i)->text() << "\t" << lstTarget->item(i)->text() << "\n";
	};
	file.close();
}
